@@ -6,7 +6,7 @@
 
 #include "FileItemLinkingPluginActionLoader.h"
 
-#include <kfileitemlistproperties.h>
+#include <KFileItemListProperties>
 #include <utils/d_ptr_implementation.h>
 #include <utils/qsqlquery_iterator.h>
 
